pub trait WrapperTypeDecode: Sized {
type Wrapped: Into<Self>;
}Expand description
A marker trait for types that can be created solely from other decodable types.
The decoding of such type is assumed to be the same as the wrapped type.
Required Associated Types
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<T> WrapperTypeDecode for Arc<T>
Available on crate features full or std only.
impl<T> WrapperTypeDecode for Arc<T>
Available on crate features
full or std only.Sourceimpl<T> WrapperTypeDecode for Rc<T>
Available on crate features full or std only.
impl<T> WrapperTypeDecode for Rc<T>
Available on crate features
full or std only.